==> customer-space-parent-1.2.61-source-release.zip: customer-space-parent-1.2.61/component/src/main/java/org/exoplatform/cs/service/CSConstants.java <==
package org.exoplatform.cs.service;

/**
 * Created by IntelliJ IDEA.
 * User: ali
 * Date: 09/01/17
 * Time: 14:39
 */
public class CSConstants {

  public static final String TICKET_CREATED = "exo.addons.cs.ticket.created";
  public static final String TICKET_UPDATED = "exo.addons.cs.ticket.updated";
  public static final String OLD_ASSIGNEE = "ticket.assignee.old";
  public static final String NEW_ASSIGNEE = "ticket.assignee.new";
  public static final String OLD_SEVERITY = "ticket.severity.old";
  public static final String NEW_SEVERITY = "ticket.severity.new";
  public static final String OLD_TYPE = "ticket.type.old";
  public static final String NEW_TYPE = "ticket.type.new";
  public static final String OLD_STATUS = "ticket.status.old";
  public static final String NEW_STATUS = "ticket.status.new";
  public static final String OLD_OWNER = "ticket.owner.old";
  public static final String NEW_OWNER = "ticket.owner.new";
  public static final String USERID = "user.id";
  public static final String TOPIC = "ticket.topic";
  public static final String SUPPORT_USER = "support";
  public static final String STATUS_OPEN = "open";
  public static final String STATUS_NEW = "new";
  public static final String STATUS_INPROGRESS = "inprogress";
  public static final String STATUS_CLOSED = "closed";
  public static final String RESOLVED_TAG = "[Resolved]";
  public static final String OLD_CUSTOMER_SATISFACTION = "ticket.customer.satisfaction.old";
  public static final String NEW_CUSTOMER_SATISFACTION = "ticket.customer.satisfaction.new";
  public static final String TIME_TO_FIRST_RESPONSE = "ticket.time.to.first.response";
  public static final String TIME_TO_RESOLUTION = "ticket.time.to.resolution";
}

==> customer-space-parent-1.5.3-source-release.zip: customer-space-parent-1.5.3/component/src/main/java/org/exoplatform/cs/service/CSConstants.java <==
package org.exoplatform.cs.service;

/**
 * Created by IntelliJ IDEA.
 * User: ali
 * Date: 09/01/17
 * Time: 14:39
 */
public class CSConstants {

  public static final String TICKET_CREATED = "exo.addons.cs.ticket.created";
  public static final String TICKET_UPDATED = "exo.addons.cs.ticket.updated";
  public static final String OLD_ASSIGNEE = "ticket.assignee.old";
  public static final String NEW_ASSIGNEE = "ticket.assignee.new";
  public static final String OLD_SEVERITY = "ticket.severity.old";
  public static final String NEW_SEVERITY = "ticket.severity.new";
  public static final String OLD_TYPE = "ticket.type.old";
  public static final String NEW_TYPE = "ticket.type.new";
  public static final String OLD_STATUS = "ticket.status.old";
  public static final String NEW_STATUS = "ticket.status.new";
  public static final String OLD_OWNER = "ticket.owner.old";
  public static final String NEW_OWNER = "ticket.owner.new";
  public static final String USERID = "user.id";
  public static final String TOPIC = "ticket.topic";
  public static final String SUPPORT_USER = "support";
  public static final String STATUS_OPEN = "open";
  public static final String STATUS_NEW = "new";
  public static final String STATUS_INPROGRESS = "inprogress";
  public static final String STATUS_CLOSED = "closed";
  public static final String RESOLVED_TAG = "[Resolved]";
  public static final String OLD_CUSTOMER_SATISFACTION = "ticket.customer.satisfaction.old";
  public static final String NEW_CUSTOMER_SATISFACTION = "ticket.customer.satisfaction.new";
  public static final String TIME_TO_FIRST_RESPONSE = "ticket.time.to.first.response";
  public static final String TIME_TO_RESOLUTION = "ticket.time.to.resolution";
  public static final String OLD_SUBSCRIPTION = "old.subscription";
  public static final String NEW_SUBSCRIPTION = "new.subscription";
  public static final String OLD_START_DATE = "old.start.date" ;
  public static final String NEW_START_DATE = "new.start.date";
  public static final String NEW_END_DATE ="new.end.date" ;
  public static final String OLD_END_DATE ="old.end.date" ;
  public static final String ACTION_NAME ="action.name" ;
  public static final String SPACE_UPDATED ="exo.addons.cs.space.updated";
}
